@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.100-10-g63bc7ce
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.101-8-g95616de
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 use Moose;
 with
@@ -212,7 +212,7 @@ sub configure
         'InstallGuide',
 
         [ 'Test::Compile'       => { ':version' => '2.039', bail_out_on_fail => 1, xt_mode => 1,
-            script_finder => [qw(:ExecFiles @Author::ETHER/Examples)] } ],
+            script_finder => [qw(:PerlExecFiles @Author::ETHER/Examples)] } ],
         [ 'Test::NoTabs'        => { ':version' => '0.08', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
         [ 'Test::EOL'           => { ':version' => '0.17', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
         'MetaTests',
@@ -246,7 +246,7 @@ sub configure
         ],
         [ 'ReadmeAnyFromPod'    => { ':version' => '0.142180', type => 'pod', location => 'root', phase => 'release' } ],
 
-        # MetaData
+        # Metadata
         $self->server eq 'github' ? [ 'GithubMeta' => { ':version' => '0.54', homepage => 0, issues => 0 } ] : (),
         [ 'AutoMetaResources'   => { 'bugtracker.rt' => 1,
               $self->server eq 'gitmo' ? ( 'repository.gitmo' => 1 )
@@ -443,7 +443,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.101
+version 0.102
 
 =head1 SYNOPSIS
 
@@ -523,7 +523,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     :version = 2.039
     bail_out_on_fail = 1
     xt_mode = 1
-    script_finder = :ExecFiles
+    script_finder = :PerlExecFiles
     script_finder = Examples
 
     [Test::NoTabs]
@@ -587,7 +587,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     phase = release
 
 
-    ;;; MetaData
+    ;;; Metadata
     [GithubMeta]    ; (if server = 'github' or omitted)
     :version = 0.54
     homepage = 0
@@ -1010,7 +1010,7 @@ Randy Stauner <rwstauner@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
