@@ -4,11 +4,12 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
 use Module::Runtime 'use_module';
+use PadWalker 'peek_sub';
 
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 
@@ -21,6 +22,12 @@ sub configure
     # containing plugin specifications. The goal is to make this look as close
     # to what weaver.ini looks like as possible.
 
+    # I wouldn't have to do this ugliness if I could have some configuration values passed in from weaver.ini or
+    # the [PodWeaver] plugin's use of config_plugin (where I could define a 'licence' option)
+    my $podweaver_plugin = ${ peek_sub(\&Dist::Zilla::Plugin::PodWeaver::weaver)->{'$self'} };
+    my $licence_plugin = $podweaver_plugin && $podweaver_plugin->zilla->plugin_named('@Author::ETHER/License');
+    my $licence_filename = $licence_plugin ? $licence_plugin->filename : 'LICENCE';
+
     return (
         '@CorePrep',
         '-SingleEncoding',
@@ -42,7 +49,7 @@ sub configure
         [ 'Region' => 'postlude' ],
         'Authors',
         [ 'Contributors' => { ':version' => '0.008' } ],
-        [ 'Legal' => { -f 'LICENCE' ? ( header => 'COPYRIGHT AND LICENCE' ) : () } ],
+        [ 'Legal' => { ':version' => '4.011', header => 'COPYRIGHT AND ' . $licence_filename } ],
         [ 'Region' => 'footer' ],
     );
 }
@@ -127,7 +134,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.101
+version 0.102
 
 =head1 SYNOPSIS
 
@@ -193,7 +200,8 @@ following F<weaver.ini>, minus some optimizations:
     :version = 0.008
 
     [Legal]
-    header = COPYRIGHT AND LICENCE ; only if file is called LICENCE
+    :version = 4.011
+    header = COPYRIGHT AND <licence filename>
 
     [Region / footer]
 
@@ -278,7 +286,7 @@ see L<KENTNL's distribution|Dist::Zilla::PluginBundle::Author::KENTNL/NAMING-SCH
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
